@@ -47,7 +47,7 @@ class matrix(np.ndarray):
             return matrix((np.asarray(self) * other))
         if isinstance(other, diffmatrix):
             assert self.dim() == 2 and self.shape == other.left_size
-            ret = create_matrix(*other.shape, "zero")
+            ret = create_matrix(*other.shape, style="zero")
             n, m = self.shape
             for i in range(n):
                 for j in range(m):
